@@ -13,6 +13,7 @@ import pandas as pd
 import threading
 import csv
 import tempfile
+import socket
 
 
 class Json:
@@ -705,9 +706,12 @@ class TasksDatabase:
             if disconnect:
                 TasksDatabase.pg_database.disconnect()
             return {'task_dict': None}
-
+        host_name = socket.gethostname()
+        host_ip = socket.gethostbyname(host_name)
         task_dict = dict(tasks[0])
-        update_values = {'started_time': datetime.datetime.now(), 'status': 'working'}
+        update_values = {'started_time': datetime.datetime.now(),
+                         'status': 'working',
+                         'worker_host': f'{host_ip} : {host_name}'}
         task_dict = TasksDatabase.pg_database.update(table=f'{schema}.tasks', values=update_values,
                                                      where={'task_id': task_dict.get('task_id')})
         TasksDatabase.pg_database.commit()
