@@ -112,6 +112,7 @@ class Worker(object):
                     params = json.loads(params)
                 if not isinstance(params, dict):
                     params = dict()
+                print(f'Started new task at {datetime.datetime.now()}; task_dict: {task_dict}')
                 return func(**params)
         except Exception as e:
             error = f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}'
@@ -163,6 +164,7 @@ class Worker(object):
             task_dict = database.get_one_task()
             # print(f'{func_name}: now={datetime.datetime.now()}; task_dict: {task_dict}')
             if isinstance(task_dict, dict):
+                task_dict = dict(task_dict)
                 if process_type is None or process_type.lower() == 'none' or process_type.lower() == '<none>':
                     timer = threading.Timer(self._timeout_sec, self.stop_woker, args=(func_name, task_dict,))
                     timer.setDaemon(True)
